@@ -7,6 +7,6 @@ has authorize_url    => 'https://github.com/login/oauth/authorize';
 has access_token_url => 'https://github.com/login/oauth/access_token';
 has user_info_url    => 'https://api.github.com/user';
 
-has moniker => sub {'github'};
+sub moniker {'github'};
 
 1;
